@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
 from _stories.exceptions import make_failure_error
 from _stories.summary import make_failure_summary
 from _stories.summary import make_success_summary
 
 
-class Call(object):
+class Call:
     def got_failure(self, ctx, method_name, reason):
         raise make_failure_error(reason)
 
@@ -15,7 +14,7 @@ class Call(object):
         pass
 
 
-class Run(object):
+class Run:
     def __init__(self, protocol):
         self.protocol = protocol
 
